@@ -1,10 +1,10 @@
 /*
-  Copyright (C) 2006 Werner Dittmann
+  Copyright (C) 2006-2007 Werner Dittmann
 
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +12,9 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Boston, MA 02111.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
+
 #ifndef _ZRTPPACKETCLEARACK_H_
 #define _ZRTPPACKETCLEARACK_H_
 
@@ -31,11 +31,12 @@
 class ZrtpPacketClearAck : public ZrtpPacketBase {
 
  public:
-     ZrtpPacketClearAck();		/* Creates a Conf2Ack packet with default data */
-     ZrtpPacketClearAck(uint8_t* data);	/* Creates a Conf2Ack packet from received data */
-     virtual ~ZrtpPacketClearAck();
-
+    ZrtpPacketClearAck();		/* Creates a ClearAck packet with default data */
+    ZrtpPacketClearAck(uint8_t* data);	/* Creates a ClearAck packet from received data */
+    virtual ~ZrtpPacketClearAck();
+  
  private:
+     ClearAckPacket_t data;
 };
 
 #endif // ZRTPPACKETCLEARACK
