@@ -1,10 +1,10 @@
 /*
-  Copyright (C) 2006 Werner Dittmann
+  Copyright (C) 2006-2007 Werner Dittmann
 
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Boston, MA 02111.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef _ZRTPSTATECLASS_H_
@@ -47,23 +46,22 @@ enum zrtpStates {
     WaitConfirm1,
     WaitConfirm2,
     WaitConfAck,
+    WaitClearAck,
     SecureState,
+    WaitErrorAck,
     numberOfStates
 };
 
 enum EventReturnCodes {
-    Fail = 0,			// Event processing failed. Process RTP data.
-    Done = 1,			// Event processing ok. Process RTP data.
-    FailDismiss = 2,		// Event processing failed, dismiss RTP data.
-    OkDismiss = 3		// Event Processing ok, dismiss RTP data.
+    Fail = 0,			// ZRTP event processing failed.
+    Done = 1,			// Event processing ok.
 };
 
 enum EventDataType {
     ZrtpInitial = 1,
     ZrtpClose,
     ZrtpPacket,
-    Timer,
-    ZrtpGoClear
+    Timer
 };
 
 typedef struct Event {
@@ -72,7 +70,6 @@ typedef struct Event {
 	uint8_t* packet;
 	int32_t* timer;
     } data;
-    uint8_t* content;
 } Event_t;
 
 
@@ -111,7 +108,7 @@ private:
      * If we are <code>Initiator</code> then resend this packet in case of
      * timeout.
      */
-    ZrtpPacketBase *sentPacket;
+    ZrtpPacketBase* sentPacket;
 
     zrtpTimer_t T1;
     zrtpTimer_t T2;
@@ -138,7 +135,9 @@ public:
     int32_t evWaitConfirm1();
     int32_t evWaitConfirm2();
     int32_t evWaitConfAck();
+    int32_t evWaitClearAck();
     int32_t evSecureState();
+    int32_t evWaitErrorAck();
 
     /**
      * Initialize and activate a timer.
@@ -172,6 +171,15 @@ public:
      */
     int32_t cancelTimer() {return parent->cancelTimer(); };
 
+    /**
+     * Prepare and send an Error packet.
+     *
+     * Preparse an Error packet and sends it. It stores the Error
+     * packet in the sentPacket variable to enable resending. The
+     * method switches to protocol state Initial.
+     */
+    int32_t sendErrorPacket(uint32_t errorCode);
+
 };
 
 #endif // _ZRTPSTATECLASS_H_
