@@ -1,10 +1,10 @@
 /*
-  Copyright (C) 2006 Werner Dittmann
+  Copyright (C) 2006-2007 Werner Dittmann
 
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Boston, MA 02111.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /*
@@ -43,6 +42,7 @@ extern char* Confirm1Msg;
 extern char* Confirm2Msg;
 extern char* Conf2AckMsg;
 extern char* ErrorMsg;
+extern char* ErrorAckMsg;
 extern char* GoClearMsg;
 extern char* ClearAckMsg;
 
@@ -56,11 +56,16 @@ extern char* iniMasterSalt;
 extern char* respMasterKey;
 extern char* respMasterSalt;
 
-extern char* hmacKey;
+extern char* iniHmacKey;
+extern char* respHmacKey;
 extern char* retainedSec;
-extern char* knownPlain;
+
+extern char* iniZrtpKey;
+extern char* respZrtpKey;
 
 extern char* sasString;
+
+extern char* KDFString;
 /**
  *
  */
@@ -102,8 +107,8 @@ extern char* supportedSASType[];
 // Keep the auth len identifers in supportedAuthLen in the same order than the
 // following enum, starting with zero.
 enum SupportedAuthLengths {
-    AuthLen80,
     AuthLen32,
+    AuthLen80,
     NumSupportedAuthLenghts
 };
 extern char *supportedAuthLen[];
