@@ -1,10 +1,10 @@
 /*
-  Copyright (C) 2006 Werner Dittmann
+  Copyright (C) 2006-2007 Werner Dittmann
 
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Boston, MA 02111.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /*
@@ -25,30 +24,23 @@
 
 #include <stdio.h>
 
-#define	ZRTP_EXT_PACKET		0x505a
+#define	ZRTP_MAGIC		0x5a525450
 
 #define ZRTP_WORD_SIZE		4
-#define ZRTP_MSG_SIZE		8 	// 2 * WORD_SIZE
+#define CRC_SIZE                4
 
-#define MESSAGE_LENGTH		2
+// The ZRTP Message header, refer to chapter 6.2ff
 typedef struct zrtpPacketHeader {
     uint16_t    zrtpId;
     uint16_t    length;
-    uint8_t     message[8];
+    uint8_t     messageType[2*ZRTP_WORD_SIZE];
 } zrtpPacketHeader_t;
 
-
-#define HELLO_LENGTH            62 /* plus the MESSAGE_LENGTH = 64 */
 typedef struct Hello {
-    uint8_t	version[4];
-    uint8_t	clientId[31];
-    uint8_t	flag;
-    uint8_t     hashes[5][8];
-    uint8_t     ciphers[5][8];
-    uint8_t     authlengths[5][8];
-    uint8_t	pubkeys[5][8];
-    uint8_t	sas[5][8];
-    uint8_t     zid[12];
+    uint8_t	version[ZRTP_WORD_SIZE];
+    uint8_t	clientId[3*ZRTP_WORD_SIZE];
+    uint8_t     zid[3*ZRTP_WORD_SIZE];
+    uint32_t	flagLength;
 } Hello_t;
 
 typedef struct HelloPacket {
@@ -56,46 +48,50 @@ typedef struct HelloPacket {
     Hello_t hello;
 } HelloPacket_t;
 
-typedef struct HelloAck {	/* Length is MESSAGE_LENGTH */
-    zrtpPacketHeader_t hdr;
-} HelloAck_t;
 
-#define COMMIT_LENGTH           21 /* plus MESSAGE_LENGTH = 23 */
+typedef struct HelloAckPacket {
+    zrtpPacketHeader_t hdr;
+    uint8_t crc[ZRTP_WORD_SIZE];
+} HelloAckPacket_t;
+
 typedef struct Commit {
-    uint8_t	zid[12];
-    uint8_t     hash[8];
-    uint8_t     cipher[8];
-    uint8_t     authlengths[8];
-    uint8_t	pubkey[8];
-    uint8_t	sas[8];
-    uint8_t	hvi[32];
+    uint8_t	zid[3*ZRTP_WORD_SIZE];
+    uint8_t     hash[ZRTP_WORD_SIZE];
+    uint8_t     cipher[ZRTP_WORD_SIZE];
+    uint8_t     authlengths[ZRTP_WORD_SIZE];
+    uint8_t	pubkey[ZRTP_WORD_SIZE];
+    uint8_t	sas[ZRTP_WORD_SIZE];
+    uint8_t	hvi[8*ZRTP_WORD_SIZE];
 } Commit_t;
 
 typedef struct CommitPacket {
     zrtpPacketHeader_t hdr;
     Commit_t commit;
+    uint8_t crc[ZRTP_WORD_SIZE];
 } CommitPacket_t;
 
-#define DHPART_LENGTH		10 /* plus MESSAGE_LENGTH + pvr length */
 typedef struct DHPart {
-    uint8_t rs1Id[8];
-    uint8_t rs2Id[8];
-    uint8_t sigsId[8];
-    uint8_t srtpsId[8];
-    uint8_t otherSecretId[8];
+    uint8_t rs1Id[2*ZRTP_WORD_SIZE];
+    uint8_t rs2Id[2*ZRTP_WORD_SIZE];
+    uint8_t sigsId[2*ZRTP_WORD_SIZE];
+    uint8_t srtpsId[2*ZRTP_WORD_SIZE];
+    uint8_t otherSecretId[2*ZRTP_WORD_SIZE];
 }  DHPart_t;
 
 typedef struct DHPartPacket {
     zrtpPacketHeader_t hdr;
+    DHPart_t dhPart;           // Since 0.4a
 } DHPartPacket_t;
 
-
-#define CONFIRM_LENGTH		2 /* the rest of Confirm data goes into payload */
 typedef struct Confirm {
-    uint8_t	plaintext[15];
-    uint8_t	flag;
+    uint8_t	hmac[2*ZRTP_WORD_SIZE];
+    uint8_t     iv[4*ZRTP_WORD_SIZE];
+    uint8_t     filler[2];
+    uint8_t     sigLength;
+    uint8_t	flags;
     uint32_t    expTime;
-    uint8_t	hmac[32];
+    uint8_t     SASRenderScheme[ZRTP_WORD_SIZE];
+    uint32_t    trustedSASValue;
 } Confirm_t;
 
 typedef struct ConfirmPacket {
@@ -103,36 +99,40 @@ typedef struct ConfirmPacket {
     Confirm_t confirm;
 } ConfirmPacket_t;
 
-#define CONF2ACK_LENGTH         2
-typedef struct Conf2Ack {
+typedef struct Conf2AckPacket {
     zrtpPacketHeader_t hdr;
-} Conf2Ack_t;
+    uint8_t     crc[ZRTP_WORD_SIZE];
+} Conf2AckPacket_t;
+
+typedef struct GoClear {
+    uint8_t clearHmac[2*ZRTP_WORD_SIZE];
+} GoClear_t;
+
+typedef struct GoClearPacket {
+    zrtpPacketHeader_t hdr;
+    GoClear_t goClear;
+    uint8_t crc[ZRTP_WORD_SIZE];
+} GoClearPacket_t;
+
+typedef struct ClearAckPacket {
+    zrtpPacketHeader_t hdr;
+    uint8_t crc[ZRTP_WORD_SIZE];
+} ClearAckPacket_t;
 
-#define ERROR_LENGTH		2 /* plus MESSAGE_LENGTH = 4 */
 typedef struct Error {
-    uint8_t type[8];
+    uint32_t errorCode;
 } Error_t;
 
 typedef struct ErrorPacket {
     zrtpPacketHeader_t hdr;
     Error_t error;
+    uint8_t crc[ZRTP_WORD_SIZE];
 } ErrorPacket_t;
 
-typedef struct GoClear {
-    uint8_t clearHmac[32];
-} GoClear_t;
-
-#define GOCLEAR_LENGTH         8 /* plus MESSAGE_LENGTH = 10 */
-typedef struct GoClearPacket {
+typedef struct ErrorAckPacket {
     zrtpPacketHeader_t hdr;
-    GoClear_t goClear;
-} GoClearPacket_t;
-
-#define CLEARACK_LENGTH         2
-typedef struct ClearAck {
-    zrtpPacketHeader_t hdr;
-} ClearAck_t;
-
+    uint8_t crc[ZRTP_WORD_SIZE];
+} ErrorAckPacket_t;
 
 /* big/little endian conversion */
 
@@ -177,3 +177,11 @@ static inline uint64_t U64_AT( void const * _p )
 
 #endif // ZRTPPACKET_H
 
+
+/** EMACS **
+ * Local variables:
+ * mode: c++
+ * c-default-style: ellemtel
+ * c-basic-offset: 4
+ * End:
+ */
